# disperseNN2

[![Documentation Status](https://readthedocs.org/projects/dispersenn2/badge/?version=latest)](https://dispersenn2.readthedocs.io/en/latest/?badge=latest)

New architecture for estimating dispersal rate from georeferenced SNPs. For details see our preprint (LINK).

For instructions, see the [docs page](https://dispersenn2.readthedocs.io/en/latest/).
